Model — pysm v3.0.0

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.0.0 »
- pysm Documentation »
- Model

# Model

class `pysm.` `Model`(nside, map_dist=None, dataurl=None)

  Bases: `object`

  This is the template object for PySM objects.

  If a MPI communicator is passed as input and `pixel_indices` is None, the class automatically distributes the maps across processes. You can implement your own pixel distribution passing both a MPI communicator and `pixel_indices`, however that won’t support smoothing with `libsharp`. If `libsharp` is available, the rings are distributed as expected by `libsharp` to perform distributed spherical harmonics transforms, see `pysm.mpi.distribute_rings_libsharp()`, the `libsharp` grid object is saved in `self.libsharp_grid`. If libsharp is not available, pixels are distributed uniformly across processes, see `pysm.mpi.distribute_pixels_uniformly()`

  Parameters
    mpi_comm: object

      MPI communicator object (optional, default=None).

    nside: int

      Resolution parameter at which this model is to be calculated.

    smoothing_lmaxint

      \(\ell_{max}\) for the smoothing step, by default \(2*N_{side}\)

  Methods Summary

  `read_map`(self, path[, unit, field]) | Wrapper of the PySM read_map function that automatically uses nside, pixel_indices and mpi_comm defined in this Model
  `read_txt`(self, path, \*\*kwargs) |

  Methods Documentation

  `read_map`(self, path, unit=None, field=0)

    Wrapper of the PySM read_map function that automatically uses nside, pixel_indices and mpi_comm defined in this Model

  `read_txt`(self, path, **kwargs)